@@ -1,4 +1,6 @@
+from zope.interface import implements
 from twisted.internet import defer
+from webut.skin import iskin
 from ldaptor.protocols.ldap import ldapsyntax
 from ldaptor import generate_password
 from ldaptor.apps.webui.uriquote import uriUnquote
@@ -8,7 +10,7 @@ from ldaptor.apps.webui import i18n
 
 import os
 from nevow import rend, inevow, loaders, url, tags
-from formless import annotate, webform, iformless, configurable
+from formless import annotate, webform, configurable
 
 class MassPasswordChangeStatus(object):
     def __init__(self, deferlist):
@@ -18,7 +20,7 @@ class MassPasswordChangeStatus(object):
 class MassPasswordChangeForm(configurable.Configurable):
     def __init__(self, ldapObjects):
         super(MassPasswordChangeForm, self).__init__(None)
-	self.ldapObjects = {}
+        self.ldapObjects = {}
         for o in ldapObjects:
             assert o.dn not in self.ldapObjects
             self.ldapObjects[o.dn] = o
@@ -26,14 +28,14 @@ class MassPasswordChangeForm(configurable.Configurable):
         self.formFields=self._getFormFields()
 
     def _getFormFields(self):
-	r=[]
+        r=[]
         r.append(annotate.Argument('request',
                                    annotate.Request()))
-	for dn, e in self.ldapObjects.items():
+        for dn, e in self.ldapObjects.items():
             r.append(annotate.Argument('dn_%s' % dn,
                                        annotate.Boolean(label=dn,
                                                         description=e)))
-	return r
+        return r
 
     def getBindingNames(self, ctx):
         return ['generate']
@@ -56,9 +58,9 @@ class MassPasswordChangeForm(configurable.Configurable):
             assert k in self.ldapObjects
             entries.append(self.ldapObjects[k])
 
-	if not entries:
-	    return _('No passwords to change.')
-	d=generate_password.generate(reactor, len(entries))
+        if not entries:
+            return _('No passwords to change.')
+        d=generate_password.generate(reactor, len(entries))
 
         def _gotPasswords(passwords, entries):
             assert len(passwords)==len(entries)
@@ -77,40 +79,31 @@ class MassPasswordChangeForm(configurable.Configurable):
 
 
 class ReallyMassPasswordChangePage(rend.Page):
+    implements(iskin.ISkinnable)
+
+    title = _('Ldaptor Mass Password Change Page')
+
     addSlash = True
     docFactory = loaders.xmlfile(
         'mass_change_password-really.xhtml',
         templateDir=os.path.split(os.path.abspath(__file__))[0])
 
     def __init__(self, entries):
-	super(ReallyMassPasswordChangePage, self).__init__()
-	self.entries = entries
+        super(ReallyMassPasswordChangePage, self).__init__()
+        self.entries = entries
 
-    def data_css(self, context, data):
-        request = context.locate(inevow.IRequest)
-        u = url.URL.fromRequest(request).clear().parent().parent().parent()
-        return [
-            u.child('form.css'),
-            u.child('ldaptor.css'),
-            ]
-
-    def render_css_item(self, context, data):
-        context.fillSlots('url', data)
-        return context.tag
-
-    def data_header(self, context, data):
-        request = context.locate(inevow.IRequest)
-        u=url.URL.fromRequest(request)
-        u=u.parent().parent()
+    def data_header(self, ctx, data):
+        u=url.URL.fromContext(ctx)
+        u=u.parentdir().parentdir().clear()
         l=[]
-	l.append(tags.a(href=u.sibling("search"))[_("Search")])
-	l.append(tags.a(href=u.sibling("add"))[_("add new entry")])
-	return l
+        l.append(tags.a(href=u.sibling("search"))[_("Search")])
+        l.append(tags.a(href=u.sibling("add"))[_("add new entry")])
+        return l
 
     def configurable_(self, context):
         request = context.locate(inevow.IRequest)
         return MassPasswordChangeForm(self.entries)
-    
+
     def render_form(self, context, data):
         return webform.renderForms()[context.tag]
 
@@ -141,6 +134,10 @@ class ReallyMassPasswordChangePage(rend.Page):
     render_i18n = i18n.render()
 
 class MassPasswordChangePage(rend.Page):
+    implements(iskin.ISkinnable)
+
+    title = _('Ldaptor Mass Password Change Page')
+
     addSlash = True
     docFactory = loaders.xmlfile(
         'mass_change_password.xhtml',
@@ -151,9 +148,8 @@ class MassPasswordChangePage(rend.Page):
         self.baseObject = baseObject
 
     def render_url(self, context, data):
-        request = context.locate(inevow.IRequest)
-        u = url.URL.fromRequest(request)
-        return context.tag(href=u.parent().child('search'))
+        u = url.URL.fromContext(context)
+        return context.tag(href=u.parentdir().child('search'))
 
     def childFactory(self, context, name):
         entry = inevow.ISession(context).getLoggedInRoot().loggedIn
