@@ -7,36 +7,39 @@ from ldaptor.protocols.ldap import ldapsyntax, autofill
 from ldaptor.protocols import pureldap
 from ldaptor.protocols.ldap.autofill import posixAccount
 from ldaptor.testutil import LDAPClientTestDriver
-from twisted.trial.util import deferredResult, deferredError
 
 class LDAPAutoFill_Posix(unittest.TestCase):
     def testMustHaveObjectClass(self):
         """Test that Autofill_posix fails unless object is a posixAccount."""
         client = LDAPClientTestDriver()
-	o=ldapsyntax.LDAPEntryWithAutoFill(client=client,
+        o=ldapsyntax.LDAPEntryWithAutoFill(client=client,
                                            dn='cn=foo,dc=example,dc=com',
                                            attributes={
-	    'objectClass': ['something', 'other'],
-	    })
+            'objectClass': ['something', 'other'],
+            })
         autoFiller = posixAccount.Autofill_posix(baseDN='dc=example,dc=com')
         d = o.addAutofiller(autoFiller)
-
-        val = deferredError(d)
-        client.assertNothingSent()
-
-        val.trap(autofill.ObjectMissingObjectClassException)
+        def _cbMustRaise(_):
+            raise unittest.FailTest('Should have raised an exception')
+        def _eb(fail):
+            client.assertNothingSent()
+            fail.trap(autofill.ObjectMissingObjectClassException)
+            return None
+        d.addCallbacks(_cbMustRaise,
+                       _eb)
+        return d
 
     def testDefaultSetting(self):
         """Test that fields get their default values."""
 
         client = LDAPClientTestDriver(
             # uid==1000 -> free
-	    [	pureldap.LDAPSearchResultDone(resultCode=0,
+            [   pureldap.LDAPSearchResultDone(resultCode=0,
                                               matchedDN='',
                                               errorMessage=''),],
 
             # gid==1000 -> taken
-	    [	pureldap.LDAPSearchResultEntry(objectName='',
+            [   pureldap.LDAPSearchResultEntry(objectName='',
                                            attributes=[('objectClass',
                                                         ('foo',
                                                          'posixAccount',
@@ -45,26 +48,26 @@ class LDAPAutoFill_Posix(unittest.TestCase):
                                               matchedDN='',
                                               errorMessage=''),],
             # gid==1500 -> free
-	    [	pureldap.LDAPSearchResultDone(resultCode=0,
+            [   pureldap.LDAPSearchResultDone(resultCode=0,
                                               matchedDN='',
                                               errorMessage=''),],
 
             # gid==1250 -> free
-	    [	pureldap.LDAPSearchResultDone(resultCode=0,
+            [   pureldap.LDAPSearchResultDone(resultCode=0,
                                               matchedDN='',
                                               errorMessage=''),],
 
             # gid==1125 -> free
-            [	pureldap.LDAPSearchResultDone(resultCode=0,
+            [   pureldap.LDAPSearchResultDone(resultCode=0,
                                               matchedDN='',
                                               errorMessage=''),],
 
             # gid==1062 -> free
-            [	pureldap.LDAPSearchResultDone(resultCode=0,
+            [   pureldap.LDAPSearchResultDone(resultCode=0,
                                               matchedDN='',
                                               errorMessage=''),],
             # gid==1031 -> free
-            [	pureldap.LDAPSearchResultEntry(objectName='',
+            [   pureldap.LDAPSearchResultEntry(objectName='',
                                                attributes=[('objectClass',
                                                             ('foo',
                                                              'posixAccount',
@@ -74,12 +77,12 @@ class LDAPAutoFill_Posix(unittest.TestCase):
                                               errorMessage=''),],
 
             # gid==1046 -> free
-            [	pureldap.LDAPSearchResultDone(resultCode=0,
+            [   pureldap.LDAPSearchResultDone(resultCode=0,
                                               matchedDN='',
                                               errorMessage=''),],
 
             # gid==1038 -> taken
-            [	pureldap.LDAPSearchResultEntry(objectName='',
+            [   pureldap.LDAPSearchResultEntry(objectName='',
                                                attributes=[('objectClass',
                                                             ('foo',
                                                              'posixAccount',
@@ -89,12 +92,12 @@ class LDAPAutoFill_Posix(unittest.TestCase):
                                               errorMessage=''),],
 
             # gid==1042 -> free
-	    [	pureldap.LDAPSearchResultDone(resultCode=0,
+            [   pureldap.LDAPSearchResultDone(resultCode=0,
                                               matchedDN='',
                                               errorMessage=''),],
 
             # gid==1040 -> taken
-            [	pureldap.LDAPSearchResultEntry(objectName='',
+            [   pureldap.LDAPSearchResultEntry(objectName='',
                                                attributes=[('objectClass',
                                                             ('foo',
                                                              'posixAccount',
@@ -104,7 +107,7 @@ class LDAPAutoFill_Posix(unittest.TestCase):
                                               errorMessage=''),],
 
             # gid==1041 -> taken
-            [	pureldap.LDAPSearchResultEntry(objectName='',
+            [   pureldap.LDAPSearchResultEntry(objectName='',
                                                attributes=[('objectClass',
                                                             ('foo',
                                                              'posixAccount',
@@ -114,15 +117,17 @@ class LDAPAutoFill_Posix(unittest.TestCase):
                                               errorMessage=''),],
            )
 
-	o=ldapsyntax.LDAPEntryWithAutoFill(client=client,
+        o=ldapsyntax.LDAPEntryWithAutoFill(client=client,
                                            dn='cn=foo,dc=example,dc=com',
                                            attributes={
-	    'objectClass': ['posixAccount', 'other'],
-	    })
+            'objectClass': ['posixAccount', 'other'],
+            })
 
         d = o.addAutofiller(posixAccount.Autofill_posix(baseDN='dc=example,dc=com'))
-        val = deferredResult(d)
+        d.addCallback(self._cb_testDefaultSetting, client, o)
+        return d
 
+    def _cb_testDefaultSetting(self, val, client, o):
         client.assertSent(
             *[
 
@@ -143,9 +148,9 @@ class LDAPAutoFill_Posix(unittest.TestCase):
             for x in (1000, 1500, 1250, 1125, 1062, 1031, 1046, 1038, 1042, 1040, 1041)])
 
         self.failUnless('loginShell' in o)
-	self.failUnlessEqual(o['loginShell'], ['/bin/sh'])
+        self.failUnlessEqual(o['loginShell'], ['/bin/sh'])
 
         self.failUnless('uidNumber' in o)
-	self.failUnlessEqual(o['uidNumber'], ['1000'])
+        self.failUnlessEqual(o['uidNumber'], ['1000'])
         self.failUnless('gidNumber' in o)
-	self.failUnlessEqual(o['gidNumber'], ['1042'])
+        self.failUnlessEqual(o['gidNumber'], ['1042'])
